#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 glirc
version:              2.40.1
visibility:           public
id:                   glirc-2.40.1-CNKPwttnJeI2oT0JqVotvM
key:                  glirc-2.40.1-CNKPwttnJeI2oT0JqVotvM
license:              ISC
copyright:            2016-2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             Console IRC client
description:
    Console IRC client

    glirc is a console IRC client with an emphasis on providing
    dynamic views into the model of your IRC connections.

    <https://github.com/glguy/irc-core/wiki Documentation Wiki>

category:             Network
abi:                  3d890ed4bfe1aed1384208af49be15da
exposed:              True
exposed-modules:
    Client.Authentication.Ecdh Client.Authentication.Ecdsa
    Client.Authentication.Scram Client.CApi Client.CApi.Exports
    Client.CApi.Types Client.Commands Client.Commands.Arguments.Parser
    Client.Commands.Arguments.Renderer Client.Commands.Arguments.Spec
    Client.Commands.Certificate Client.Commands.Channel
    Client.Commands.Chat Client.Commands.Connection
    Client.Commands.Docs Client.Commands.Exec
    Client.Commands.Interpolation Client.Commands.Operator
    Client.Commands.Queries Client.Commands.Recognizer
    Client.Commands.TabCompletion Client.Commands.Toggles
    Client.Commands.Types Client.Commands.Window
    Client.Commands.WordCompletion Client.Commands.ZNC
    Client.Configuration Client.Configuration.Colors
    Client.Configuration.Macros Client.Configuration.Notifications
    Client.Configuration.ServerSettings Client.Configuration.Sts
    Client.Docs Client.EventLoop Client.EventLoop.Actions
    Client.EventLoop.Errors Client.EventLoop.Network Client.Hook
    Client.Hook.DroneBLRelay Client.Hook.Matterbridge
    Client.Hook.Snotice Client.Hook.Znc.Buffextras Client.Hooks
    Client.Image Client.Image.Layout Client.Image.LineWrap
    Client.Image.Message Client.Image.MircFormatting
    Client.Image.PackedImage Client.Image.Palette
    Client.Image.StatusLine Client.Image.Textbox Client.Log Client.Mask
    Client.Message Client.Network.Async Client.Network.Connect
    Client.Options Client.State Client.State.Channel
    Client.State.EditBox Client.State.EditBox.Content
    Client.State.Extensions Client.State.Focus Client.State.Network
    Client.State.Url Client.State.Window Client.UserHost Client.View
    Client.View.Cert Client.View.ChannelInfo Client.View.ChannelList
    Client.View.Digraphs Client.View.Help Client.View.IgnoreList
    Client.View.KeyMap Client.View.MaskList Client.View.Mentions
    Client.View.Messages Client.View.Palette Client.View.RtsStats
    Client.View.UrlSelection Client.View.UserList Client.View.Who
    Client.View.Windows Client.WhoReply

hidden-modules:
    ContextFilter DigraphQuote Digraphs LensUtils RtsStats StrQuote
    StrictUnit Paths_glirc Build_glirc

import-dirs:          /usr/lib/ghc-9.6.6/site-local/glirc-2.40.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.40.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/glirc-2.40.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/glirc
hs-libraries:         HSglirc-2.40.1-CNKPwttnJeI2oT0JqVotvM
include-dirs:         /usr/lib/ghc-9.6.6/site-local/glirc-2.40.1/include
includes:             include/glirc-api.h
depends:
    HsOpenSSL-0.11.7.9-3vrZadETao5JtXy1jmJ1qb
    async-2.2.6-HVFcnXCzrULJJSPrXugzlh
    attoparsec-0.14.4-5JdM0c7xj70IPbvJjnzZkg base-4.18.2.1
    base64-bytestring-1.2.1.0-7yPZQqczHUsxqD5FnMd56 bytestring-0.11.5.3
    config-schema-1.3.0.0-3JyAwGnQjwfEXh0WkuQfa2
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    curve25519-0.2.8.1-Ck0ETiS9JZS5CYAiXOZy11 directory-1.3.8.5
    filepath-1.4.300.1 free-5.2-F3cIVGrfTH6EWs5tewOzs0
    githash-0.1.6.3-xOIk0R3aDCH0Z3blr3x0w
    hashable-1.4.7.0-IVKAR4D6WU9H8t6zzGQ76p
    hookup-0.8-CqrIuZZrLMsBhMgPorxsnI
    irc-core-2.12-C8cLiEr81Au2ku1o8taqE5
    kan-extensions-5.2.8-E346BA6wdqTICvbRcJSxJn
    lens-5.3.4-FLE2Mpdc2NQ9IUFEHfSpBl
    network-3.1.4.0-5QGUGxzwH322yW8TioI43L
    psqueues-0.2.8.3-5xOMEtwdQlS43E9e3qGskE
    random-1.2.1.3-DTsWC2j5NX8JAyBJGSl6m
    regex-tdfa-1.3.2.5-6tX5Z8DRWKX4ukPh2wCajT
    semigroupoids-6.0.2-GmRcOe3hZZw3xvFFVLVUaZ
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 typed-process-0.2.13.0-8AFAzO4YgqwC5HW4xrieVo
    unix-2.8.4.0 unordered-containers-0.2.20.1-FX7g4DMKoiaDV91wUmRzTu
    vector-0.13.2.0-E81GJWrGuCo4SgJOIsfBQo
    vty-6.2-AZaxFeMF0eXFdXRDe44fbc

haddock-interfaces:   /usr/share/doc/glirc/html/glirc.haddock
haddock-html:         /usr/share/doc/glirc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

